#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-better-errors
version:              0.9.1.4
visibility:           public
id:                   aeson-better-errors-0.9.1.4-4l2DjNgHKaN97ccRjv6y24
key:                  aeson-better-errors-0.9.1.4-4l2DjNgHKaN97ccRjv6y24
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/aeson-better-errors
synopsis:             Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.

    See also <http://harry.garrood.me/blog/aeson-better-errors/>.

category:             Text, Web, JSON
abi:                  874f1a1bff6820bbd98903b092b211fc
exposed:              True
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal

hidden-modules:       Data.Aeson.BetterErrors.Utils
import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-better-errors-0.9.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-better-errors-0.9.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-better-errors-0.9.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-better-errors
hs-libraries:         HSaeson-better-errors-0.9.1.4-4l2DjNgHKaN97ccRjv6y24
depends:
    aeson-2.2.2.0-6c1DCPq2cjw7mSOIGM724W base-4.18.2.1
    bytestring-0.11.5.3 dlist-1.0-B7D1vsARFiIHVaGk5CGbYO mtl-2.3.1
    scientific-0.3.8.1-DFmvyClKolsDKaqDO41mzB text-2.0.2
    transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    unordered-containers-0.2.20.1-Hsa9d2Ja6XgAATZt7ZTK9f
    vector-0.13.2.0-CQhR7DRX3H037jPZymXmiQ
    void-0.7.4-Ab78HEYVlxC2PerDGXO6Wd

haddock-interfaces:
    /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock

haddock-html:         /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

